import 'package:alan/alan.dart';
import 'package:grpc/grpc.dart';
import 'package:test/test.dart';
import 'package:http/http.dart' as http;
import 'package:alan/proto/cosmos/bank/v1beta1/export.dart' as bank;

void main() {
  final channel = ClientChannel(
    'localhost',
    port: 9090,
    options: const ChannelOptions(credentials: ChannelCredentials.insecure()),
  );

  tearDown(() async {
    await channel.shutdown();
  });

  test('send transaction', () async {
    final networkInfo = NetworkInfo(
      bech32Hrp: 'cosmos',
      fullNodeHost: 'http://localhost',
    );
    final mnemonic = [
      'sibling',
      'auction',
      'sibling',
      'flavor',
      'judge',
      'foil',
      'tube',
      'dust',
      'work',
      'mixed',
      'crush',
      'action',
      'menu',
      'property',
      'project',
      'ride',
      'crouch',
      'hat',
      'mom',
      'scale',
      'start',
      'ill',
      'spare',
      'panther',
    ];
    final wallet = Wallet.derive(mnemonic, networkInfo);

    final msgSend = bank.MsgSend.create()
      ..fromAddress = wallet.bech32Address
      ..toAddress = 'cosmos1hlwe7u0mkr5jlh9ya2hy7lq84pzq4ua9c4vh4g';
    msgSend.amount.add(
      Coin.create()
        ..amount = '100'
        ..denom = 'stake',
    );

    final signer = TxSigner.build(channel, http.Client());
    final signedTx = await signer.createAndSign(wallet, [msgSend]);

    final sender = TxSender.build(channel);
    final response = await sender.broadcastTx(signedTx);
    print(response.rawLog);
  });
}
